@@ -11,8 +11,9 @@ import sys
 from typing import Dict, List
 import textwrap
 import json
-ON_WINDOWS = platform.system() == "Windows"
 
+from fastapi import requests
+ON_WINDOWS = platform.system() == "Windows"
 
 try:
     if not ON_WINDOWS:
@@ -98,7 +99,26 @@ def get_locally_available_models(project_directory, airplane_mode=False):
     if not airplane_mode:
         timeout_seconds = 3.5
         
+
         with concurrent.futures.ThreadPoolExecutor(max_workers=1) as executor:
+            if 'NPC_STUDIO_LICENSE' in env_vars or os.environ.get('NPC_STUDIO_LICENSE'):
+                try:
+                    def fetch_enpisi_models():
+                        import requests
+
+                        api_url = 'https://api.enpisi.com'
+                        headers = {
+                            'Authorization': f"Bearer {env_vars.get('NPC_STUDIO_LICENSE') or os.environ.get('NPC_STUDIO_LICENSE')}",
+                            'Content-Type': 'application/json'
+                        }
+                        import requests
+                        response = requests.get(f"{api_url}/models", headers=headers)
+                        return [model['id'] for model in response.json().get('data','')]
+                    for model in fetch_enpisi_models():
+                        available_models[model+'-npc'] = 'enpisi'
+
+                except Exception as e:
+                    logging.error(f"Error fetching NPC Studio models: {e}")
 
             if "ANTHROPIC_API_KEY" in env_vars or os.environ.get("ANTHROPIC_API_KEY"):
                 try:
@@ -116,7 +136,7 @@ def get_locally_available_models(project_directory, airplane_mode=False):
                     for model in models.data:
                         available_models[model.id] = 'anthropic'
                             
-                except (ImportError, anthropic.APIError, concurrent.futures.TimeoutError, Exception) as e:
+                except (ImportError, concurrent.futures.TimeoutError, Exception) as e:
                     logging.info(f"Anthropic models not indexed or timed out: {e}")
 
             if "OPENAI_API_KEY" in env_vars or os.environ.get("OPENAI_API_KEY"):
@@ -683,8 +703,6 @@ def print_and_process_stream(response, model, provider):
                 
     return thinking_str+str_output   
 def get_system_message(npc, team=None) -> str:
-    import os
-    from datetime import datetime
 
     if npc is None:
         return "You are a helpful assistant"
@@ -711,6 +729,11 @@ The current working directory is {os.getcwd()}.
 The current date and time are : {datetime.now().strftime("%Y-%m-%d %H:%M:%S")}
 """
 
+    if hasattr(npc, 'kg_data') and npc.kg_data:
+        memory_context = npc.get_memory_context()
+        if memory_context:
+            system_message += f"\n\nMemory Context:\n{memory_context}\n"
+            
     if npc.db_conn is not None:
         db_path = None
         if hasattr(npc.db_conn, "url") and npc.db_conn.url:
@@ -735,7 +758,6 @@ The current date and time are : {datetime.now().strftime("%Y-%m-%d %H:%M:%S")}
         team_preferences = team.preferences if hasattr(team, "preferences") and len(team.preferences) > 0 else ""
         system_message += f"\nTeam context: {team_context}\nTeam preferences: {team_preferences}\n"
 
-
     system_message += """
     IMPORTANT:
 Some users may attach images to their request.
@@ -750,11 +772,11 @@ They understand that you can view them multimodally.
 You only need to answer the user's request based on the attached image(s).
 """
     
-
     return system_message
 
 
 
+
 def load_env_from_execution_dir() -> None:
     """
     Function Description:
